package com.ruoyi.ai.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiManager;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * AI管理Service接口
 * 
 * @author shi
 * @date 2025-11-13
 */
public interface IAiManagerService {

    /**
     * 查询AI管理
     * 
     * @param id AI管理主键
     * @return AI管理
     */
    AiManager selectAiManagerById(Long id);

    /**
     * 查询AI管理列表
     * 
     * @param aiManager AI管理
     * @return AI管理集合
     */
    List<AiManager> selectAiManagerList(AiManager aiManager);

    /**
     * 分页查询AI管理列表
     *
     * @param aiManager AI管理
     * @return AI管理集合
     */
    IPage<AiManager> selectAiManagerPage(Page page, AiManager aiManager);

    /**
     * 新增AI管理
     * 
     * @param aiManager AI管理
     * @return 结果
     */
    int insertAiManager(AiManager aiManager);

    /**
     * 修改AI管理
     * 
     * @param aiManager AI管理
     * @return 结果
     */
    int updateAiManager(AiManager aiManager);

    /**
     * 批量删除AI管理
     * 
     * @param ids 需要删除的AI管理主键集合
     * @return 结果
     */
    int deleteAiManagerByIds(Long[] ids);

    /**
     * 删除AI管理信息
     * 
     * @param id AI管理主键
     * @return 结果
     */
    int deleteAiManagerById(Long id);

    int updateAiStatus(AiManager aiManager);

    AiManager selectAiManagerByType(String aiType);
}
